@@ -17,11 +17,6 @@ Usage:
 	If you pass no test names, it runs all tests
 	Accepted environment variables:
 	KEY_PRESS_DELAY (e.g. 200): the number of milliseconds to wait between keypresses
-	MODE:
-		* ask (default): if a snapshot test fails, asks if you want to update the snapshot
-		* check: if a snapshot test fails, exits with an error
-		* update: if a snapshot test fails, updates the snapshot
-		* sandbox: uses the test's setup step to run the test in a sandbox where you can do whatever you want
 
 	TUI mode:
 		> go run cmd/integration_test/main.go tui
