@@ -53,10 +53,10 @@ func TestBranchGetCommitDifferences(t *testing.T) {
 
 func TestBranchNewBranch(t *testing.T) {
 	runner := oscommands.NewFakeRunner(t).
-		Expect(`git checkout -b "test" "master"`, "", nil)
+		Expect(`git checkout -b "test" "refs/heads/master"`, "", nil)
 	instance := buildBranchCommands(commonDeps{runner: runner})
 
-	assert.NoError(t, instance.New("test", "master"))
+	assert.NoError(t, instance.New("test", "refs/heads/master"))
 	runner.CheckForMissingCalls()
 }
 
@@ -162,54 +162,62 @@ func TestBranchGetAllBranchGraph(t *testing.T) {
 	assert.NoError(t, err)
 }
 
-func TestBranchCurrentBranchName(t *testing.T) {
+func TestBranchCurrentBranchInfo(t *testing.T) {
 	type scenario struct {
 		testName string
 		runner   *oscommands.FakeCmdObjRunner
-		test     func(string, string, error)
+		test     func(BranchInfo, error)
 	}
 
 	scenarios := []scenario{
 		{
 			"says we are on the master branch if we are",
 			oscommands.NewFakeRunner(t).Expect(`git symbolic-ref --short HEAD`, "master", nil),
-			func(name string, displayname string, err error) {
+			func(info BranchInfo, err error) {
 				assert.NoError(t, err)
-				assert.EqualValues(t, "master", name)
-				assert.EqualValues(t, "master", displayname)
+				assert.EqualValues(t, "master", info.RefName)
+				assert.EqualValues(t, "master", info.DisplayName)
+				assert.False(t, info.DetachedHead)
 			},
 		},
 		{
-			"falls back to git `git branch --contains` if symbolic-ref fails",
+			"falls back to git `git branch --points-at=HEAD` if symbolic-ref fails",
 			oscommands.NewFakeRunner(t).
 				Expect(`git symbolic-ref --short HEAD`, "", errors.New("error")).
-				Expect(`git branch --contains`, "* master", nil),
-			func(name string, displayname string, err error) {
+				Expect(`git branch --points-at=HEAD --format="%(HEAD)%00%(objectname)%00%(refname)"`, "*\x006f71c57a8d4bd6c11399c3f55f42c815527a73a4\x00(HEAD detached at 6f71c57a)\n", nil),
+			func(info BranchInfo, err error) {
 				assert.NoError(t, err)
-				assert.EqualValues(t, "master", name)
-				assert.EqualValues(t, "master", displayname)
+				assert.EqualValues(t, "6f71c57a8d4bd6c11399c3f55f42c815527a73a4", info.RefName)
+				assert.EqualValues(t, "(HEAD detached at 6f71c57a)", info.DisplayName)
+				assert.True(t, info.DetachedHead)
 			},
 		},
 		{
-			"handles a detached head",
+			"handles a detached head (LANG=zh_CN.UTF-8)",
 			oscommands.NewFakeRunner(t).
 				Expect(`git symbolic-ref --short HEAD`, "", errors.New("error")).
-				Expect(`git branch --contains`, "* (HEAD detached at 123abcd)", nil),
-			func(name string, displayname string, err error) {
+				Expect(
+					`git branch --points-at=HEAD --format="%(HEAD)%00%(objectname)%00%(refname)"`,
+					"*\x00679b0456f3db7c505b398def84e7d023e5b55a8d\x00（头指针在 679b0456 分离）\n"+
+						" \x00679b0456f3db7c505b398def84e7d023e5b55a8d\x00refs/heads/master\n",
+					nil),
+			func(info BranchInfo, err error) {
 				assert.NoError(t, err)
-				assert.EqualValues(t, "123abcd", name)
-				assert.EqualValues(t, "(HEAD detached at 123abcd)", displayname)
+				assert.EqualValues(t, "679b0456f3db7c505b398def84e7d023e5b55a8d", info.RefName)
+				assert.EqualValues(t, "（头指针在 679b0456 分离）", info.DisplayName)
+				assert.True(t, info.DetachedHead)
 			},
 		},
 		{
 			"bubbles up error if there is one",
 			oscommands.NewFakeRunner(t).
 				Expect(`git symbolic-ref --short HEAD`, "", errors.New("error")).
-				Expect(`git branch --contains`, "", errors.New("error")),
-			func(name string, displayname string, err error) {
+				Expect(`git branch --points-at=HEAD --format="%(HEAD)%00%(objectname)%00%(refname)"`, "", errors.New("error")),
+			func(info BranchInfo, err error) {
 				assert.Error(t, err)
-				assert.EqualValues(t, "", name)
-				assert.EqualValues(t, "", displayname)
+				assert.EqualValues(t, "", info.RefName)
+				assert.EqualValues(t, "", info.DisplayName)
+				assert.False(t, info.DetachedHead)
 			},
 		},
 	}
@@ -218,7 +226,7 @@ func TestBranchCurrentBranchName(t *testing.T) {
 		s := s
 		t.Run(s.testName, func(t *testing.T) {
 			instance := buildBranchCommands(commonDeps{runner: s.runner})
-			s.test(instance.CurrentBranchName())
+			s.test(instance.CurrentBranchInfo())
 			s.runner.CheckForMissingCalls()
 		})
 	}
