@@ -13,6 +13,7 @@ const (
 	COMMIT_ICON         = "\ufc16" // ﰖ
 	MERGE_COMMIT_ICON   = "\ufb2c" // שּׁ
 	DEFAULT_REMOTE_ICON = "\uf7a1" // 
+	STASH_ICON          = "\uf01c" // 
 )
 
 type remoteIcon struct {
@@ -28,7 +29,7 @@ var remoteIcons = []remoteIcon{
 }
 
 func IconForBranch(branch *models.Branch) string {
-	if branch.DisplayName != "" {
+	if branch.DetachedHead {
 		return DETACHED_HEAD_ICON
 	}
 	return BRANCH_ICON
@@ -59,3 +60,7 @@ func IconForRemote(remote *models.Remote) string {
 	}
 	return DEFAULT_REMOTE_ICON
 }
+
+func IconForStash(stash *models.StashEntry) string {
+	return STASH_ICON
+}
